@@ -22,7 +22,10 @@ from ...utils import load_hash_vectors
 @pytest.mark.requires_backend_interface(interface=HMACBackend)
 class TestHMACMD5(object):
     test_hmac_md5 = generate_hmac_test(
-        load_hash_vectors, "HMAC", ["rfc-2202-md5.txt"], hashes.MD5(),
+        load_hash_vectors,
+        "HMAC",
+        ["rfc-2202-md5.txt"],
+        hashes.MD5(),
     )
 
 
@@ -33,7 +36,10 @@ class TestHMACMD5(object):
 @pytest.mark.requires_backend_interface(interface=HMACBackend)
 class TestHMACSHA1(object):
     test_hmac_sha1 = generate_hmac_test(
-        load_hash_vectors, "HMAC", ["rfc-2202-sha1.txt"], hashes.SHA1(),
+        load_hash_vectors,
+        "HMAC",
+        ["rfc-2202-sha1.txt"],
+        hashes.SHA1(),
     )
 
 
@@ -44,7 +50,10 @@ class TestHMACSHA1(object):
 @pytest.mark.requires_backend_interface(interface=HMACBackend)
 class TestHMACSHA224(object):
     test_hmac_sha224 = generate_hmac_test(
-        load_hash_vectors, "HMAC", ["rfc-4231-sha224.txt"], hashes.SHA224(),
+        load_hash_vectors,
+        "HMAC",
+        ["rfc-4231-sha224.txt"],
+        hashes.SHA224(),
     )
 
 
@@ -55,7 +64,10 @@ class TestHMACSHA224(object):
 @pytest.mark.requires_backend_interface(interface=HMACBackend)
 class TestHMACSHA256(object):
     test_hmac_sha256 = generate_hmac_test(
-        load_hash_vectors, "HMAC", ["rfc-4231-sha256.txt"], hashes.SHA256(),
+        load_hash_vectors,
+        "HMAC",
+        ["rfc-4231-sha256.txt"],
+        hashes.SHA256(),
     )
 
 
@@ -66,7 +78,10 @@ class TestHMACSHA256(object):
 @pytest.mark.requires_backend_interface(interface=HMACBackend)
 class TestHMACSHA384(object):
     test_hmac_sha384 = generate_hmac_test(
-        load_hash_vectors, "HMAC", ["rfc-4231-sha384.txt"], hashes.SHA384(),
+        load_hash_vectors,
+        "HMAC",
+        ["rfc-4231-sha384.txt"],
+        hashes.SHA384(),
     )
 
 
@@ -77,7 +92,10 @@ class TestHMACSHA384(object):
 @pytest.mark.requires_backend_interface(interface=HMACBackend)
 class TestHMACSHA512(object):
     test_hmac_sha512 = generate_hmac_test(
-        load_hash_vectors, "HMAC", ["rfc-4231-sha512.txt"], hashes.SHA512(),
+        load_hash_vectors,
+        "HMAC",
+        ["rfc-4231-sha512.txt"],
+        hashes.SHA512(),
     )
 
 
